// Models
var Post = Backbone.Model.extend({
  urlRoot: '/api/posts.json'
});

// Collections
var PostCollection = Backbone.Collection.extend({
  model: Post,
  url: '/api/posts.json'
});

// View
var PostListView = Backbone.View.extend({
  id: 'posts',
  initialize: function() {
    this.model.bind("reset", this.render, this);
  },

  render: function(eventName) {
    _.each(this.model.models, function(post) {
      $(this.el).append(new PostListItemView({
        model: post
      }).render().el);
    },
    this);
    return this;
  }
});

var PostListItemView = Backbone.View.extend({
  initialize: function() {
    this.template = Handlebars.compile($('#postTemplate').html());
  },
  className: 'post',
  render: function(eventName) {
    $(this.el).html(this.template(this.model.toJSON()));
    return this;
  }

});

// Application Router
var AppRouter = Backbone.Router.extend({

  routes: {
    '': 'home',
    '/post/:id': 'post'
  },

  initialize: function() {
    var sideBarTemplate = Handlebars.compile($('#sidebarItem').html());
    this.lastPosts = 10;
    if (!this.sidebarloaded) {
      $.getJSON('api/sidebar.json', function(data) {
          $('#sidebar').html(sideBarTemplate(data));
      });
      this.sidebarloaded = true;
    }
  },

  home: function() {
    // Load posts
    if (!this.postList) {
      console.log('Getting last ' + this.lastPosts + ' posts.');
      this.postList = new PostCollection();
      this.postList.fetch();
    };
    this.postListView = new PostListView({
      model: this.postList
    });
    $('#content').html(this.postListView.render().el);
  },

  post: function(id) {
    if (this.postList) {
      this.post = this.postList.get(id);
      this.postView = new PostListItemView({
        model: this.post
      });
      console.log('Collection already loaded.')
      console.log(this.post);
      $('#content').html(this.postView.render().el);
    } else {
      this.post = new Post({
        id: id
      });
      this.post.fetch({
        success: function(model, resp) {
          if (resp == null) { 
            $('#content').html('Post not found.');
            return
          };
          this.postView = new PostListItemView({
            model: model
          });
          $('#content').html(this.postView.render().el);
        },
        error: function(model, resp) {
          console.log('Post not found.');
          new Error({ message: 'Could not find that document.' });
          window.location.hash = '#';
        }
      });
    }
  }

});
app = new AppRouter();
Backbone.history.start();
(function($) {
  // JQuery stuff goes here
})(jQuery);

